<?php
/**
 * Initialize the options before anything else. 
 */
add_action( 'admin_init', 'custom_theme_options', 1 );

function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Create your own custom array that will be passes to the 
   * OptionTree Settings API Class.
   */
  $custom_settings = array(
    'contextual_help' => array(
      'content'       => array( 
        array(
          'id'        => 'general_help',
          'title'     => 'General',
          'content'   => '<p>Help content goes here!</p>'
        )
      ),
      'sidebar'       => '<p>Sidebar content goes here!</p>',
    ),
    'sections'        => array(
      array(
        'id'          => 'general',
        'title'       => 'General'
      ),
      array(
        'title'       => 'Social Icons ',
        'id'          => 'social-icons'
      ),
	  array(
	  	'title' 	  => 'Custom Home Layout',
		'id'		  => 'custom-home-details'
	  ),
	  array(
	  	'title' 	  => 'Home Details',
		'id'		  => 'home-details'
	  ),
	  array(
	  	'title' 	  => 'Product Details',
		'id'		  => 'product-details'
	  ),
	  array(
	  	'title' 	  => 'Contact Details',
		'id'		  => 'contact'
	  ),
	  array(
	  	'title' 	  => 'Color Settings',
		'id'		  => 'color-settings'
	  ),
	  array(
	  	'title' 	  => 'Font Settings',
		'id'		  => 'font-settings'
	  ),
	  array(
	  	'title' 	  => 'Background Settings',
		'id'		  => 'background-settings'
	  )

    ),
    'settings'        => array(
	
      array(
        'label'       => 'Select site logo type',
        'id'          => 'logo_type',
        'type'        => 'select',
        'desc'        => 'Choose the site logo type. You can either use site\'s name or your logo',
        'choices'     => array(
          array(
            'label'       => 'Use Logo',
            'value'       => 'logo'
          ),
          array(
            'label'       => 'Use Site Name',
            'value'       => 'name'
          )
        ),
        'std'         => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
		  
		array(
        'label'       => 'Upload Your Logo',
        'id'          => 'upload_logo',
        'type'        => 'upload',
        'desc'        => 'Upload your logo. Logo size must be lower than 195px width and 65px height.',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
		array(
        'label'       => 'Upload Your Favico',
        'id'          => 'upload_favico',
        'type'        => 'upload',
        'desc'        => 'Upload your favico.ico file. This is the image file will be shown at the left side of address bar. Must be sized as 16x16 pixels.',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	
      array(
        'id'          => 'theme_layout',
        'label'       => 'Layout',
        'desc'        => 'Choose a layout for your theme',
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'general',
        'class'       => '',
        'choices'     => array(
          array(
            'value'   => 'left-sidebar',
            'label'   => 'Left Sidebar',
            'src'     => OT_URL . '/assets/images/layout/left-sidebar.png'
          ),
          array(
            'value'   => 'right-sidebar',
            'label'   => 'Right Sidebar',
            'src'     => OT_URL . '/assets/images/layout/right-sidebar.png'
          ),
          array(
            'value'   => 'full-width',
            'label'   => 'Full Width (no sidebar)',
            'src'     => OT_URL . '/assets/images/layout/full-width.png'
          )
        )
      ),
	  
	  
	  array(
        'label'       => 'Enable Boxed Layout',
        'id'          => 'boxed_layout_active',
        'type'        => 'checkbox',
        'desc'        => 'Check this if you want to use the iceMag Theme with Boxed Layout',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'Disable Header Shadow',
        'id'          => 'disable_header_shadow',
        'type'        => 'checkbox',
        'desc'        => 'If you want to disable the shadow under header, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'Disable Social Icons',
        'id'          => 'disable_all_social_icons',
        'type'        => 'checkbox',
        'desc'        => 'If you want to disable the social icons under header, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'Disable Search Box',
        'id'          => 'disable_search_box',
        'type'        => 'checkbox',
        'desc'        => 'If you want to disable the search box under header, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'Disable Under Header',
        'id'          => 'disable_all_under_header',
        'type'        => 'checkbox',
        'desc'        => 'If you want to disable all the header under menu (social icons, search box and shadow effect) check this option.',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
            'label'       => 'Footer Copyright Information',
            'id'          => 'footer_copyright',
            'type'        => 'textarea-simple',
            'desc'        => 'Your copyright information. You may use HTML tags here',
			'section'     => 'general',
            'std'         => 'Designed by <a href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" target="_blank">XanderRock</a> © 2013 <a href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" target="_blank">iceMag Theme</a> | All Rights Reserved',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
      ),
	  
	 array(
            'label'   => 'Read More Text',
            'id'      => 'read_more_text',
            'desc'    => 'Enter read more text you want to use in "read more" details',
			'section' => 'general',
            'std'     => 'read more',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
          ),
      array(
        'label'       => 'SEO Slug Settings',
        'id'          => 'seo_settings_header',
        'type'        => 'textblock-titled',
        'desc'        => '<p>You can change the slugs down below for better SEO usage. This way, you can change the name of your products slug as you like. !Important : If you see 404 Error when you change the slug options, go to "Settings > Permalinks" in Wordpress Dashboard and choose "Post name" and click "Save Changes" button. Even if your settings shows "Post name" click on the "Save Changes" button to flush.</p>',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'iceMag Products Slug',
        'id'          => 'icemag_products_slug',
        'type'        => 'text',
        'desc'        => 'iceMag Products slug to show in links.',
        'std'         => 'icemagproducts',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'Testimonials Slug',
        'id'          => 'icemag_testimonials_slug',
        'type'        => 'text',
        'desc'        => 'Testimonials slug to show in links.',
        'std'         => 'testimonials',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'iceMag Gallery Slug',
        'id'          => 'icemag_gallery_slug',
        'type'        => 'text',
        'desc'        => 'iceMag Gallery slug to show in links.',
        'std'         => 'icemaggallery',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'References Slug',
        'id'          => 'icemag_references_slug',
        'type'        => 'text',
        'desc'        => 'References slug to show in links.',
        'std'         => 'references',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),

	  array(
        'label'       => 'Our Team Slug',
        'id'          => 'icemag_ourteam_slug',
        'type'        => 'text',
        'desc'        => 'Our Team slug to show in links.',
        'std'         => 'ourteam',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
      array(
        'label'       => 'Pagination Settings',
        'id'          => 'pagination_settings_header',
        'type'        => 'textblock-titled',
        'desc'        => '<p>You can change the post numbers of the pages for using the pagination.</p>',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),

      array(
        'label'       => 'Products Per page',
        'id'          => 'products-per-page',
        'type'        => 'text',
        'desc'        => 'Products per page to show.',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
      array(
        'label'       => 'Gallery Image Per page',
        'id'          => 'gallery-per-page',
        'type'        => 'text',
        'desc'        => 'Gallery image per page to show.',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
      array(
        'label'       => 'Gallery Filtered Two Column',
        'id'          => 'gallery-filtered-two-total',
        'type'        => 'text',
        'desc'        => 'Total gallery image to show in filtered gallery two column.',
        'std'         => '6',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
      array(
        'label'       => 'Gallery Filtered Three Column',
        'id'          => 'gallery-filtered-three-total',
        'type'        => 'text',
        'desc'        => 'Total gallery image to show in filtered gallery three column.',
        'std'         => '9',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
      array(
        'label'       => 'Gallery Filtered Four Column',
        'id'          => 'gallery-filtered-four-total',
        'type'        => 'text',
        'desc'        => 'Total gallery image to show in filtered gallery four column.',
        'std'         => '8',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
      array(
        'label'       => 'Gallery Filtered Six Column',
        'id'          => 'gallery-filtered-six-total',
        'type'        => 'text',
        'desc'        => 'Total gallery image to show in filtered gallery six column.',
        'std'         => '18',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),
	  
	  array(
        'label'       => 'Footer Large Disabled',
        'id'          => 'footer_large_enabled',
        'type'        => 'checkbox',
        'desc'        => 'Check this if you don\'t want large footer (footer with four columns) at the bottom',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'general'
      ),

	  
	  
	 
          array(
            'label'       => 'Facebook',
            'id'          => 'social_icons_facebook',
            'type'        => 'text',
            'desc'        => 'Your facebook link',
			'section'     => 'social-icons',
            'std'         => 'http://facebook.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Linkedin',
            'id'          => 'social_icons_linkedin',
            'type'        => 'text',
            'desc'        => 'Your linkedin link',
			'section'     => 'social-icons',
            'std'         => 'http://linkedin.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Twitter',
            'id'          => 'social_icons_twitter',
            'type'        => 'text',
            'desc'        => 'Your twitter link',
			'section'     => 'social-icons',
            'std'         => 'http://twitter.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Digg',
            'id'          => 'social_icons_digg',
            'type'        => 'text',
            'desc'        => 'Your digg link',
			'section'     => 'social-icons',
            'std'         => 'http://digg.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Google+',
            'id'          => 'social_icons_google',
            'type'        => 'text',
            'desc'        => 'Your google plus link',
			'section'     => 'social-icons',
            'std'         => 'http://google.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		  array(
            'label'       => 'Pinterest',
            'id'          => 'social_icons_pinterest',
            'type'        => 'text',
            'desc'        => 'Your Pinterest Link',
			'section'     => 'social-icons',
            'std'         => '',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),

		  
          array(
            'label'       => 'Youtube',
            'id'          => 'social_icons_youtube',
            'type'        => 'text',
            'desc'        => 'Your youtube channel link',
			'section'     => 'social-icons',
            'std'         => '',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Skype',
            'id'          => 'social_icons_skype',
            'type'        => 'text',
            'desc'        => 'Your skype information',
			'section'     => 'social-icons',
            'std'         => 'http://skype.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Vimeo',
            'id'          => 'social_icons_vimeo',
            'type'        => 'text',
            'desc'        => 'Your vimeo link',
			'section'     => 'social-icons',
            'std'         => 'http://vimeo.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
          array(
            'label'       => 'Instagram',
            'id'          => 'social_icons_instagram',
            'type'        => 'text',
            'desc'        => 'Your instagram link',
			'section'     => 'social-icons',
            'std'         => 'http://instagram.com',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),



	   array(
        'label'       => 'Twitter Tweet',
        'id'          => 'twitter_tweet',
        'type'        => 'checkbox',
        'desc'        => 'Check this if you want to activate the Twitter button at blog posts',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'Yes',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'social-icons'
      ),

	   array(
        'label'       => 'Facebook Like',
        'id'          => 'facebook_like',
        'type'        => 'checkbox',
        'desc'        => 'Check this if you want to activate the Facebook Like button at blog posts',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'Yes',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'social-icons'
      ),
	   array(
        'label'       => 'Google +1 Share',
        'id'          => 'google_share',
        'type'        => 'checkbox',
        'desc'        => 'Check this if you want to activate the Google+ button at blog posts',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'Yes',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'social-icons'
      ),
	   array(
        'label'       => 'Pinterest Pinit',
        'id'          => 'pinterest',
        'type'        => 'checkbox',
        'desc'        => 'Check this if you want to activate the Pinterest button at blog posts',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'social-icons'
      ),
	  
	  
      array(
        'label'       => 'Select homepage layout',
        'id'          => 'home_layout',
        'type'        => 'select',
        'desc'        => 'Choose the homepage layout type.',
        'choices'     => array(
          array(
            'label'       => 'Home Business',
            'value'       => 'business'
          ),
          array(
            'label'       => 'Home Business Static',
            'value'       => 'business-static'
          ),
          array(
            'label'       => 'Home Application',
            'value'       => 'application'
          ),
          array(
            'label'       => 'Home Photography',
            'value'       => 'photography'
          ),
          array(
            'label'       => 'Home Education',
            'value'       => 'education'
          ),
          array(
            'label'       => 'Home Social Media Marketing',
            'value'       => 'social'
          ),
          array(
            'label'       => 'Home Blog',
            'value'       => 'blog'
          ),
          array(
            'label'       => 'Home Layout Custom',
            'value'       => 'custom'
          ),
        ),
        'std'         => 'business',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'home-details'
      ),
	  
		array(
            'label'       => 'Home Business Slider ID',
            'id'          => 'home_business_slider_id',
            'type'        => 'text',
            'desc'        => 'Enter the Layer Slider\'s shortcode here',
			'section'	  => 'home-details',
            'std'         => '[layerslider id="2"]',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
	  
		array(
            'label'       => 'Home Business Shortcodes',
            'id'          => 'home_business_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Business Template.',
			'section'	  => 'home-details',
            'std'         => '[promotionBox button="PURCHASE" href="http://themeforest.net/user/XanderRock/portfolio"][iconicTextBoxed icon="bars" header="Right Time!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="map" header="Responsive Touch!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="monitor" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Cloud Tech" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="settings" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Global Solutions!" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][clear][br][ReferencesPost width="full"][Notification type="info"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
		array(
            'label'       => 'Home Business Static Shortcodes',
            'id'          => 'home_business_static_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Business Static Template. This template does not use slider to look static',
			'section'	  => 'home-details',
            'std'         => '[addImg src="http://as3doctor.com/icemag-theme/files/2012/12/business-portfolio-theme.jpg" alt="Business Clean Portfolio"][iconic4 header="Responsive Touch!" text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec volutpat ante eget purus egestas id eleifend lorem aliquet. " icon="touch" link="http://themeforest.net/user/XanderRock/portfolio"][iconic4 header="Right Time!" text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec volutpat ante eget purus" icon="clock" link="http://themeforest.net/user/XanderRock/portfolio"][iconic4 header="Cloud Tech" text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec volutpat ante eget purus" icon="cloud" link="http://themeforest.net/user/XanderRock/portfolio"][iconic4 header="Global Solutions!" text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec volutpat ante eget purus" icon="globe" link="http://themeforest.net/user/XanderRock/portfolio"][br][br][br][headerText header="What We Do?" text=""][container][inColumn column="eight"][latestPosts total="3"][/inColumn][inColumn column="eight"][layerslider id="6"][/inColumn][/container]</p>
<p>[TestimonialsPost width="full"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
		  
		array(
            'label'       => 'Home Photography Slider ID',
            'id'          => 'home_photography_slider_id',
            'type'        => 'text',
            'desc'        => 'Enter the Layer Slider\'s shortcode here',
			'section'	  => 'home-details',
            'std'         => '[layerslider id="3"]',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
	  
		array(
            'label'       => 'Home Photography Shortcodes',
            'id'          => 'home_photography_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Photography Template.',
			'section'	  => 'home-details',
            'std'         => '[hrText header="Hi, I\'m John Doe and this is my photography blog" text="You can find my latest photos here. I love catching the beauty of the nature. "][headerText header="John Doe Gallery" text=""][icemagGalleryFiltered total="8" columns="four" ][clear][br][promotionBox header="We\'d like to hear from you" title="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam porttitor, arcu sed mattis faucibus, sapien sem egestas turpis, ut vulputate nibh enim in turpis." button="CONTACT US" href="themeforest.net/user/XanderRock/portfolio?ref=XanderRock"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
		  
		array(
            'label'       => 'Home Application Slider ID',
            'id'          => 'home_application_slider_id',
            'type'        => 'text',
            'desc'        => 'Enter the Layer Slider\'s shortcode here',
			'section'	  => 'home-details',
            'std'         => '[layerslider id="1"]',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
	  
		array(
            'label'       => 'Home Application Shortcodes',
            'id'          => 'home_application_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Application Template.',
			'section'	  => 'home-details',
            'std'         => '[promotionBox header="Our newest application is now on the Store" title="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec volutpat ante eget purus egestas id eleifend lorem aliquet. Pellentesque fermentum magna ut mi aliquet venenatis vel consequat est. " button="BUY NOW" href="http://themeforest.net/user/XanderRock/portfolio"][br][productsColumn total="3" columns="three" paging="no"][headerText header="Our Awesome Application" text=""][iconicTextBoxed icon="bars" header="Right Time!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="map" header="Responsive Touch!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="monitor" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Cloud Tech" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="settings" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Global Solutions!" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][clear][br][container][inColumn column="eight"][TestimonialsPost width="half"][/inColumn][inColumn column="eight"][latestPosts total="2"][/inColumn][/container]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
		  
		array(
            'label'       => 'Home Education Slider ID',
            'id'          => 'home_education_slider_id',
            'type'        => 'text',
            'desc'        => 'Enter the Layer Slider\'s shortcode here',
			'section'	  => 'home-details',
            'std'         => '[layerslider id="4"]',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
	  
		array(
            'label'       => 'Home Education Shortcodes',
            'id'          => 'home_education_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Education Template.',
			'section'	  => 'home-details',
            'std'         => '<p>[iconic4 header="Touch on Success" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Donec vol utpat ante eget purus" icon="touch" link="http://themeforest.net/user/XanderRock/portfolio"][iconic4 header="Right Time!" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Donec vol utpat ante eget purus" icon="clock" link="http://themeforest.net/user/XanderRock/portfolio"][iconic4 header="Beyond Imagination" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Donec vol utpat ante eget purus" icon="cloud" link="http://themeforest.net/user/XanderRock/portfolio"][iconic4 header="Global Degree" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Donec vol utpat ante eget purus" icon="globe" link="http://themeforest.net/user/XanderRock/portfolio"][br][br][headerText header="Lessons" text=""][container][inColumn column="eight"][layerslider id="6"][/inColumn][inColumn column="eight"][tabs] [tab title="Shortcodes"][h1]Shortcodes Support[/h1]Donec a sem urna, quis lacinia metus. Morbi tortor nibh, lobortis in scelerisque a, ultrices at nulla. Donec ante massa, fermentum id rhoncus vel, vestibulum a orci. Morbi ullamcorper tincidunt vulputate. Praesent sed lacinia mauris. Quisque imperdiet, tortor eget varius convallis, justo risus tincidunt lectus, sit amet bibendum metus mauris a tortor. Sed accumsan, dui vel convallis placerat, sapien nisi lobortis elit, et fringilla turpis velit eget elit.[/tab] [tab title="Support"] Curabitur dolor massa, varius a accumsan sed, sagittis eget nibh. Duis convallis, leo non adipiscing cursus, leo metus fermentum magna, aliquet sollicitudin nisi orci nec ante. Suspendisse potenti. Quisque placerat erat consectetur justo bibendum commodo id at quam. &amp;nbsp; Quisque ultricies enim vitae enim imperdiet blandit. Ut consectetur nisi nec lacus accumsan at molestie ante fermentum. Nam vitae arcu ullamcorper eros posuere facilisis et in felis. Praesent leo urna, eleifend id mollis placerat, interdum ac nulla. Aliquam luctus accumsan massa non pretium. [/tab] [tab title="Price"] Curabitur dolor massa, varius a accumsan sed, sagittis eget nibh. Duis convallis, leo non adipiscing cursus, leo metus fermentum magna, aliquet sollicitudin nisi orci nec ante. Suspendisse potenti. Quisque placerat erat consectetur justo bibendum commodo id at quam. &amp;nbsp; Quisque ultricies enim vitae enim imperdiet blandit. Ut consectetur nisi nec lacus accumsan at molestie ante fermentum. Nam vitae arcu ullamcorper eros posuere facilisis et in felis. Praesent leo urna, eleifend id mollis placerat, interdum ac nulla. Aliquam luctus accumsan massa non pretium. [/tab] [/tabs][/inColumn][/container]</p>
<p>&nbsp;</p>
<p>[container]</p>
<p>[inColumn column="eight"][h1]Use Blockquotes[/h1]Integer tempor volutpat velit, in sagittis justo cursus molestie. Morbi fringilla orci nec sapien elementum scelerisque varius lorem pulvinar. Donec lacinia felis non ante accumsan vitae dictum nibh pulvinar. Donec in nisl hendrerit et venenatis lectus auctor. Phasellus eros enim, accumsan in suscipit et, accumsan quis justo.</p>
<p> [/inColumn]</p>
<p>[inColumn column="eight"][h1]Use Headers[/h1]Mauris blandit malesuada lacus accumsan iaculis. Sed metus libero, pharetra non ultrices ut, lobortis ut lectus. Pellentesque enim massa, posuere a bibendum non, vulputate at est. Nunc lobortis justo aliquet nunc bibendum placerat. Praesent venenatis posuere ante dictum luctus. Etiam eu velit libero, a dictum diam. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.</p>
<p>[/inColumn]</p>
<p>[/container]</p>
<p>[container]<br />[inColumn column="five"]<br />[type]D[/type]onec sollicitudin lorem in nisl hendrerit et venenatis lectus auctor. Phasellus eros enim, accumsan in suscipit et, accumsan quis justo. Nam rhoncus aliquam nulla vel mattis. Maecenas tortor odio, pretium sit amet euismod vitae, auctor in tellus.<br />[/inColumn]</p>
<p>[inColumn column="six"]<br />[type]M[/type]auris blandit malesuada lacus accumsan iaculis. Sed metus libero, pharetra non ultrices ut, lobortis ut lectus. Pellentesque enim massa, posuere a bibendum non, vulputate at est. Nunc lobortis justo aliquet nunc bibendum placerat. Praesent venenatis posuere ante dictum luctus.<br />[/inColumn]</p>
<p>[inColumn column="five"]<br />[type]L[/type]orem ipsum dolor sit amet, consectetur adipiscing elit. Aenean feugiat dapibus neque vitae ornare. Mauris sapien eros, hendrerit ullamcorper pharetra sed, consequat ut magna. Vivamus et sollicitudin lectus. Vivamus commodo vulputate elit.<br />[/inColumn]</p>
<p>[/container][clear]</p>
<p>&nbsp;</p>
<p>&nbsp;</p>
<p>&nbsp;</p>',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
		array(
            'label'       => 'Home Social Media Slider ID',
            'id'          => 'home_social_slider_id',
            'type'        => 'text',
            'desc'        => 'Enter the Layer Slider\'s shortcode here',
			'section'	  => 'home-details',
            'std'         => '[layerslider id="5"]',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
	  
		array(
            'label'       => 'Home Social Shortcodes',
            'id'          => 'home_social_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Social Template.',
			'section'	  => 'home-details',
            'std'         => '[Notification type="approve"][iconicTextBoxed icon="bars" header="Right Time!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="map" header="Responsive Touch!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="monitor" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Cloud Tech" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="settings" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Global Solutions!" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][clear][br][br][headerText header="Our Plans" text=""]</p>
<p>[pricingTable columns="three"][table header="Basic" price="€499" href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock"][tableList title="Lorem ipsum" option="GB"][tableList title="Lorem ipsum" option="Bandwidth"][tableList title="Lorem ipsum" option="E-mail"][tableList title="GNU" option="OS"][tableList title="1.8Ghz" option="CPU"][/table]</p>
<p>[table header="Gold" price="£499" href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock"][tableList title="Lorem ipsum" option="GB"][tableList title="Lorem ipsum" option="Bandwidth"][tableList title="Lorem ipsum" option="E-mail"][tableList title="Lorem OS" option="OS"][tableList title="1.4Ghz" option="CPU"][/table]</p>
<p>[table header="Silver" price="$499" href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" recommended="BEST"][tableList title="Lorem ipsum" option="GB"][tableList title="Lorem ipsum" option="Bandwidth"][tableList title="Lorem ipsum" option="E-mail"][tableList title="Linux" option="OS"][tableList title="1.8Ghz" option="CPU"][/table]</p>
<p>[table header="Platinum" price="£499" href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock"][tableList title="Lorem ipsum" option="GB"][tableList title="Lorem ipsum" option="Bandwidth"][tableList title="Lorem ipsum" option="E-mail"][tableList title="CN OS" option="OS"][tableList title="1.8Ghz" option="CPU"][/table]</p>
<p>[table header="Platinum" price="£499" href="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock"][tableList title="Lorem ipsum" option="GB"][tableList title="Lorem ipsum" option="Bandwidth"][tableList title="Lorem ipsum" option="E-mail"][tableList title="CN OS" option="OS"][tableList title="1.8Ghz" option="CPU"][/table]<br />[/pricingTable]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	
		  
		array(
            'label'       => 'Home Blog Shortcode',
            'id'          => 'home_blog_shortcodes',
            'type'        => 'textarea',
            'desc'        => 'This is the content field of the Home Blog page. If you are using blog as your home page, you can add extra contents here. You can use sliders or other shortcodes as you like. Keep in mind, anything you include here, will be visible at the top on the pagination.',
			'section'	  => 'home-details',
            'std'         => '',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
	   array(
        'label'       => 'Disable Layer Slider',
        'id'          => 'disable_layer_slider',
        'type'        => 'checkbox',
        'desc'        => 'If you want to disable the Layer Slider, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'home-details'
      ),
	  
		  
		array(
            'label'       => 'Home Button Name',
            'id'          => 'home_button_name_text',
            'type'        => 'text',
            'desc'        => 'Text of the home button. You can use some other words for home.',
			'section'	  => 'home-details',
            'std'         => 'Home',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Home Products Link',
            'id'          => 'home_products_link',
            'type'        => 'text',
            'desc'        => 'If you want to activate to link button at the iceMag Slider Home Page Layout, add the link here',
			'section'	  => 'home-details',
            'std'         => 'http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Testimonials Post Header Text',
            'id'          => 'home_testimonial_text',
            'type'        => 'text',
            'desc'        => 'Header text of the testimonials',
			'section'	  => 'home-details',
            'std'         => 'Testimonials',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'References Post Header Text',
            'id'          => 'home_references_text',
            'type'        => 'text',
            'desc'        => 'Header text of the references',
			'section'	  => 'home-details',
            'std'         => 'References',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  		  
		array(
            'label'       => 'Contact Page Header',
            'id'          => 'contact_page_header',
            'type'        => 'text',
            'desc'        => 'Header text of the contact page',
			'section'	  => 'home-details',
            'std'         => 'Contact Us',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		  
		  
		  
		  /*
		  	CUSTOM HOME FIELDS
		  */
		  
		array(
            'label'       => 'Custom Home Slider / Header Image Shortcode Field',
            'id'          => 'custom_home_header_slider',
            'type'        => 'textarea',
            'desc'        => 'This is the header slide/image field for custom home layout. You can use any shortcode for this area. If you want to use Layer Slider, add it\'s shortcode (i.e. [layerslider id="1"]). If you want to use another slider or an image, add it\'s shortcode here.',
			'section'	  => 'custom-home-details',
            'std'         => '[layerslider id="1"]<p>&nbsp;</p><p>&nbsp;</p>',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	
		  
	  array(
        'label'       => 'Activate Fullwidth Slider Area',
        'id'          => 'custom_home_header_slider_fullwidth',
        'type'        => 'checkbox',
        'desc'        => 'If you want to use a slider with fullwidth, check this option. Attention! Using a fullwidth slider may cause responsivity problems.',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
			'section'	  => 'custom-home-details',
      ),
		  
		array(
            'label'       => 'Custom Home Content Area 1',
            'id'          => 'custom_home_content1',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '[promotionBox button="PURCHASE" href="http://themeforest.net/user/XanderRock/portfolio"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	 
		  
		array(
            'label'       => 'Custom Home Content Area 2',
            'id'          => 'custom_home_content2',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '[TestimonialsPost width="half"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	
		  
		array(
            'label'       => 'Custom Home Content Area 3',
            'id'          => 'custom_home_content3',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '[ReferencesPost width="half"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	
		  
		array(
            'label'       => 'Custom Home Content Area 4',
            'id'          => 'custom_home_content4',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '[TestimonialsPost][ReferencesPost]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Custom Home Content Area 5',
            'id'          => 'custom_home_content5',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '[hrText header="iceMag - Awesome Responsive Wordpress Theme" text="We focus on quality on every work we do, and the success becomes our follower"]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Custom Home Content Area 6',
            'id'          => 'custom_home_content6',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Custom Home Content Area 7',
            'id'          => 'custom_home_content7',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Custom Home Content Area 8',
            'id'          => 'custom_home_content8',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		array(
            'label'       => 'Custom Home Content Area 9',
            'id'          => 'custom_home_content9',
            'type'        => 'textarea',
            'desc'        => 'You can use any shortcode or HTML codes here. This field is content field for the Custom Home Layout. If you don\'t want to use this field, leave empty',
			'section'	  => 'custom-home-details',
            'std'         => '[iconicTextBoxed icon="bars" header="Right Time!" link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="map" header="Responsive Touch!"  link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="monitor"  link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Cloud Tech" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."][iconicTextBoxed icon="settings"  link="http://themeforest.net/user/XanderRock/portfolio?ref=XanderRock" header="Global Solutions!" text="Lorem ipsum dolor sit amet, cons ectetur adipiscing elit. Duis sit amet leo lorem. Cras eros dolor, porta sit amet aliquam etra."]<p>&nbsp;</p>',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),	  
		  
	  /*
	  	END OF CUSTOM HOME FIELDS
	  */
	  
	  /*
	  	PRODUCTS DETAILS - Fullwidth / sidebar / headerImage etc
	  */
	  
      array(
        'id'          => 'product_layout',
        'label'       => 'Product Single Page Layout',
        'desc'        => 'Choose a layout for your product single page layout',
        'std'         => 'full-width',
        'type'        => 'radio-image',
        'section'     => 'product-details',
        'class'       => '',
        'choices'     => array(
          array(
            'value'   => 'left-sidebar',
            'label'   => 'Left Sidebar',
            'src'     => OT_URL . '/assets/images/layout/left-sidebar.png'
          ),
          array(
            'value'   => 'right-sidebar',
            'label'   => 'Right Sidebar',
            'src'     => OT_URL . '/assets/images/layout/right-sidebar.png'
          ),
          array(
            'value'   => 'full-width',
            'label'   => 'Full Width (no sidebar)',
            'src'     => OT_URL . '/assets/images/layout/full-width.png'
          )
        )
      ),
	  
	   array(
        'label'       => 'Product Single Header Effect',
        'id'          => 'deactivate_product_single_header',
        'type'        => 'checkbox',
        'desc'        => 'Product single page comes with a header image with PrettyPhoto effect. If you don\'t want to use the header image effect, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'Yes',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'product-details'
      ),
	  
	   array(
        'label'       => 'Product Single Remove Header',
        'id'          => 'deactivate_product_single_header_all',
        'type'        => 'checkbox',
        'desc'        => 'If you don\'t want header image at all, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'Yes',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'product-details'
      ),
	  
	   array(
        'label'       => 'Product Single Show Related',
        'id'          => 'show_related_products',
        'type'        => 'checkbox',
        'desc'        => 'If you want to show related products check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'no',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'product-details'
      ),
	  
	   array(
        'label'       => 'Total Related Products',
        'id'          => 'total_related_products',
        'type'        => 'text',
        'desc'        => 'Only works if you activated the related products. Total number of the related products to show',
        'std'         => '4',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'product-details'
      ),
	  
	  
	   array(
        'label'       => 'Related Products Columns',
        'id'          => 'columns_of_related_products',
        'type'        => 'select',
        'desc'        => 'Only works if you activated the related products. Columns number of the related products.',
		'choices'     => array(
          array(
            'label'       => 'Six Columns',
            'value'       => 'six'
          ),
          array(
            'label'       => 'Four Columns',
            'value'       => 'four'
          ),
          array(
            'label'       => 'Three Columns',
            'value'       => 'three'
          ),
          array(
            'label'       => 'Two Columns',
            'value'       => 'two'
          ),
        ),
        'std'         => 'four',
        'rows'        => '',
        'class'       => '',
        'section'     => 'product-details'
      ),
	  
	   array(
        'label'       => 'Show Product Comments',
        'id'          => 'show_product_comments',
        'type'        => 'checkbox',
        'desc'        => 'Activates / Deactivates the comment are in the products entirely. If you activate this, you also need to activate the comments on your product posts.',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => 'no',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'product-details'
      ),
	  

	  
	  /*
	  	END OF PRODUCT DETAILS
	  */
		array(
            'label'       => 'Contact Information',
            'id'          => 'contact_details',
            'type'        => 'textarea',
            'desc'        => 'Enter your contact details here. You may use HTML tags.',
			'section'	  => 'contact',
            'std'         => '[hSmall]Where We Are?[/hSmall]

[h1]iceMag Theme Incorporation[/h1]Vestibulum aliquet mi at nisi posuere eget aliquam leo congue. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Etiam a adipiscing enim. Pellentesque auctor nisi rutrum leo dignissim ornare faucibus nulla aliquam. Integer gravida, metus id molestie vestibulum, mi ligula ultricies metus, hendrerit facilisis ligula sem imperdiet leo. Duis nec leo ante, et imperdiet lectus.<br/>
[h4]Addresses[/h4]<img src="'.F_WAY.'/images/demo/logo.png" style="float:right" />

Warner Blvd, Los Angeles
California
United States of America
<br/>
 
[strong]Phone : [/strong] +123 555 5 555
[strong]E mail :[/strong] [link href="info@as3doctor.com" text="info@as3doctor.com"]
<br/><br/>
[clear]',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
		  
		  
		array(
            'label'       => 'Contact Page Header',
            'id'          => 'contact_page_header',
            'type'        => 'text',
            'desc'        => 'Header text of the contact form in the contact page',
			'section'	  => 'contact',
            'std'         => 'Contact Us',
            'post_type'   => '',
            'taxonomy'    => '',
            'class'       => ''
          ),
	  
	  array(
        'label'       => 'Deactivate Contact Bot Control',
        'id'          => 'contact_deactivate_captcha',
        'type'        => 'checkbox',
        'desc'        => 'If you don\'t want to use the "Are You Human?" bot control field in the contact form, check this option',
        'choices'     => array(
          array (
            'label'       => 'Yes',
            'value'       => 'Yes'
          )
        ),
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
		'section'	  => 'contact',
      ),
	  
	  
      array(
        'label'       => 'CSS',
        'id'          => 'my_css',
        'type'        => 'css',
        'desc'        => 'DO NOT MAKE ANY CHANGES HERE',
        'std'         => '
		
		.nav ul ul li:first-child, ul.nav ul li:first-child, #footer, .box-shadow-dark, .gallery-view,
		.details-area-class, .details-area-reg-class, .details-border, .details-area-big-reg, .tabs_content_container,
		.sidebar > li > ul > li, .tabs-side-nav > li > a, .tabs-side-content-holder,
		.view a.info, .toggle-header, .video-container {
			border-color:{{g_site_color|color}};
		}
		
		
		.header-text-container .view-all, .btn-colored-hover-nav, .header-under-line, .comments-submit, #comments-submit,
		.commentlist .reply a, #cancel-comment-reply-link, #icemag-search input[type=search]:hover, 
		.icemag-incontent-button, .control, #toTop, .generalBtn a:hover, .navigation a, .date-area,
		.plan_title, .plan_buy a:hover, .header-text-container .view-all, .view a.info{
			background-color:{{g_site_color|color}};
		}
		
		a, ol.commentlist li.comment div.vcard cite.fn, .small-header-text-container > span.small-header-text a:hover,
		.products-holder .small-header-text-container a:hover, .toggle-header, .our-team .name, .plan_price,
		.tabs-side-nav > li > a, .load-gallery > li a:hover, .load-gallery > li.active a, .iconic-text-boxed a:hover{
			color:{{g_site_color|color}};
		}		
		
		body{
			background-image:url("{{background_texture|background-image}}");	
			color:{{g_font_color|color}};
		}
		
		#body-container-small{
			border-color:{{body_container_bg_color|color}};	
		}
		
		.nav a{
			color:{{nav_text_color|color}};	
		}
		
		.nav > ul > li > ul, ul.nav > li > ul, .nav ul ul ul, ul.nav ul ul{
			background-color:{{sub_nav_bg_color|color}} !important;
		}
		
		.nav-hover-color{
			color:{{nav_hover_color|color}} !important;
		}
		
		.boxed-layout{
			border-color:{{boxed_layout_border_color|color}};	
		}
		
		.header-text-container > span.left , .header-text-container > span.right, .small-dots,
		.sidebar-header-text-container > span.left , .sidebar-header-text-container > span.right,
		.small-header-text-container > span.left , .small-header-text-container > span.right{
			background:url("{{icemag_style|background-image}}");	
		}
		
		#header-top a, .postmetadata > a:hover, h1, h2, h3, h4, h5, h6, h6 > a, a>h6, .text-input,
		ol.commentlist li.comment p, .small-h1, .testimonial-intext, .testimonial, .testimonial-author span,
		.sidebar, .sidebar-header-text-container > span.sidebar-header-text, .navigation, .navigation > span.page-numbers,
		.small-header-text-container > span.small-header-text, .small-header-text-container > span.small-header-text a,
		.post-details, .blog-bottom-details-class, .selectNav, .header-text-container > span.header-text{
			color:{{g_header_color|color}};
		}
		
		.social-icon-class, input[type="search"]{
			background-color:{{social_icons_bg|color}};
		}
		
		.generalBtn a, .plan_buy a{
			background-color:{{button_bg_color|color}};
			color:{{button_a_color|color}} !important;
		}
		
		.generalBtn a:hover{
			color:{{button_a_hover_color|color}} !important;	
		}
		
		.iconic-text-boxed, .boxed-info-field, .sidebar .widget_archive li, .sidebar .widget_categories li, .testimonial, .tagcloud a,
		.container > div.ls-lightskin, #wp-calendar tbody td, .sidebar > li > ul > li, .details-area-reg-class,
		.tabs_content_container, .togglebox, .tabs li.active a, .inputs-class, .inputs-class-num, .tabs li a:hover,
		.plan_price, .plan_features:nth-child(odd), .plan_buy,.tabs-side-nav > li > a.open_tab, 
		.tabs-side-nav > li > a:hover, .tabs-side-content-holder, .toggle-header:hover, .details-area-class{
			background-color:{{site_content_box_color|color}};
		}
		
		.tabs li.active a, .tabs li a:hover{
			border-color:{{site_content_box_color|color}};	
		}
		
		.products-two, .iconic-text-boxed > div, #wp-calendar tbody td:hover, .details-area-big-reg,
		.tabs, .tabs li a, .plan_features:nth-child(even), .tabs-side-nav > li > a, .toggle-header{
			background-color:{{g_site_light_color|color}};	
		}
		
		#wp-calendar tbody td:hover, .inputs-class, .inputs-class-num{
			border-color:{{g_site_light_color|color}};
		}
		
		.widget-title{
			color:{{footer_widget_title_color|color}};
			border-color:{{footer_widget_border_color|color}};
		}		
		
		#footer{
			color:{{footer_text_color|color}};	
			background-color:{{footer_background_color|color}};
			background-image:url("{{upload_footer_texture|background-image}}");
		}
		
		#footer-bottom{
			background-color:{{footer_bottom_color|color}};	
			color:{{footer_bottom_text_color|color}};
		}
		
		#footer-bottom a{
			color:{{footer_bottom_link_color|color}};	
		}
		
		.boxed-layout{
			background-color:{{boxed_bg_color|color}};
		}
		
		#body-container-small{
			background-image:url("{{upload_header_bg_image|background-image}}");
		}
		
		#footer a{
			color:{{footer_link_color|color}};
		}
		
		/*
			FONT FAMILIES
		*/
		
		body{
			{{google_fonts_general}}
			font-size:{{site_font_size}} ;
		}
		
		.nav, .nav a{
			font-size:{{site_nav_font_size}} !important;
			{{google_fonts_menu}}
		}
		
		.header-text-container, .header-text-container .view-all, h3.widget-title, .load-gallery > li,
		.small-h1, .sidebar-header-text-container, .small-header-text-container, .view a.info{
			{{google_fonts_header}}
		}
		
		.view{
			{{google_fonts_thumb}}
		}
		h1, h2, h3, h4, h5, h6{
			{{google_fonts_header}}
		}
		
		/*
			END OF FONT FAMILIES
		*/		
		
		',
        'rows'        => '20',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	 
	array(
        'label'       => 'General Font Color',
        'id'          => 'g_font_color',
        'type'        => 'colorpicker',
        'desc'        => 'Main font color of the theme',
        'std'         => '#3D3D3D',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Site General Color',
        'id'          => 'g_site_color',
        'type'        => 'colorpicker',
        'desc'        => 'Site general color and main menu background color',
        'std'         => '#00aae8',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Content box\'s background color',
        'id'          => 'site_content_box_color',
        'type'        => 'colorpicker',
        'desc'        => 'Background color of the content boxes',
        'std'         => '#f0f0f0',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Site General Light Color',
        'id'          => 'g_site_light_color',
        'type'        => 'colorpicker',
        'desc'        => 'General light color of the theme. There are some specific field which uses light colors for backgrounds. You can change them here',
        'std'         => '#f5f5f5',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Header underline color',
        'id'          => 'body_container_bg_color',
        'type'        => 'colorpicker',
        'desc'        => 'The color under the header area',
        'std'         => '#d5d5d5',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Menu Text Color',
        'id'          => 'nav_text_color',
        'type'        => 'colorpicker',
        'desc'        => 'Navigation (Menu) text color',
        'std'         => '#6d6d6d',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Menu Hover Color',
        'id'          => 'nav_hover_color',
        'type'        => 'colorpicker',
        'desc'        => 'Navigation (Menu) hover (mouse over) color',
        'std'         => '#fefeff',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),

	array(
        'label'       => 'Submenu Background Color',
        'id'          => 'sub_nav_bg_color',
        'type'        => 'colorpicker',
        'desc'        => 'Submenu\'s background color',
        'std'         => '#f9f9f9',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	  
	  
	array(
        'label'       => 'Boxed Layout Background Color',
        'id'          => 'boxed_bg_color',
        'type'        => 'colorpicker',
        'desc'        => 'Background color of the boxed layout',
        'std'         => '#f9f9f9',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Boxed Layout Border Color',
        'id'          => 'boxed_layout_border_color',
        'type'        => 'colorpicker',
        'desc'        => 'Border color of the boxed layout',
        'std'         => '#e4e4e4',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'General Header and font color',
        'id'          => 'g_header_color',
        'type'        => 'colorpicker',
        'desc'        => 'Site general header color',
        'std'         => '#666666',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Social Icons and Search Background',
        'id'          => 'social_icons_bg',
        'type'        => 'colorpicker',
        'desc'        => 'Social Icons and search box regular background color',
        'std'         => '#5c5c5c',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Button Background Color',
        'id'          => 'button_bg_color',
        'type'        => 'colorpicker',
        'desc'        => 'Background color of the buttons',
        'std'         => '#5c5c5c',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Button Text Color',
        'id'          => 'button_a_color',
        'type'        => 'colorpicker',
        'desc'        => 'Text color of the buttons',
        'std'         => '#FEFEFF',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Button Text Hover Color',
        'id'          => 'button_a_hover_color',
        'type'        => 'colorpicker',
        'desc'        => 'Text hover color of the buttons',
        'std'         => '#f0f0f0',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Footer Large Background Color',
        'id'          => 'footer_background_color',
        'type'        => 'colorpicker',
        'desc'        => 'Footer large (footer area width widgets) background color',
        'std'         => '#EEEEEE',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  	  
	array(
        'label'       => 'Footer Bottom Background Color',
        'id'          => 'footer_bottom_color',
        'type'        => 'colorpicker',
        'desc'        => 'Footer bottom background color.',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),	  
	  
	array(
        'label'       => 'Footer Header Text Color',
        'id'          => 'footer_widget_title_color',
        'type'        => 'colorpicker',
        'desc'        => 'Header text color of the footer',
        'std'         => '#969696',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Footer Header Border Color',
        'id'          => 'footer_widget_border_color',
        'type'        => 'colorpicker',
        'desc'        => 'Border color of the footer\'s header',
        'std'         => '#B4B6B7',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Footer Text Color',
        'id'          => 'footer_text_color',
        'type'        => 'colorpicker',
        'desc'        => 'Footer text color',
        'std'         => '#383838',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Footer Large Link Color',
        'id'          => 'footer_link_color',
        'type'        => 'colorpicker',
        'desc'        => 'Footer large link color',
        'std'         => '#00AAE8',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),
	  
	array(
        'label'       => 'Footer Bottom Text Color',
        'id'          => 'footer_bottom_text_color',
        'type'        => 'colorpicker',
        'desc'        => 'Footer bottom text color',
        'std'         => '#B5B5B5',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),

	array(
        'label'       => 'Footer Bottom Link Color',
        'id'          => 'footer_bottom_link_color',
        'type'        => 'colorpicker',
        'desc'        => 'Footer bottom link color',
        'std'         => '#6F6F6F',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'color-settings'
      ),


	/*
		FONT SETTINGS	  
	*/
	 array(
            'label'   => 'Google Font\'s Standart Code',
            'id'      => 'google_font_js',
            'desc'    => 'Enter general code of the google font.',
			'section' => 'font-settings',
            'std'     => '',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
          ),
		  
	 array(
            'label'   => 'Site General Font Google Font CSS Code',
            'id'      => 'google_fonts_general',
            'desc'    => 'Enter the CSS Codes of the Google Font you\'ve selected for site\'s general font',
			'section' => 'font-settings',
            'std'     => 'font-family: "Open Sans", sans-serif;',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
          ),
		  
	 array(
            'label'   => 'Site Navigation (Menu) Font Google Font CSS Code',
            'id'      => 'google_fonts_menu',
            'desc'    => 'Enter the CSS Codes of the Google Font you\'ve selected for site\'s general font',
			'section' => 'font-settings',
            'std'     => '',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
          ),
	  
	 array(
            'label'   => 'Products Thumbnail Font Google Font CSS Code',
            'id'      => 'google_fonts_thumb',
            'desc'    => 'Enter the CSS Codes of the Google Font you\'ve selected for site\'s thumbnails font',
			'section' => 'font-settings',
            'std'     => '',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
          ),
		  
	 array(
            'label'   => 'Header\'s Google Font CSS Code ',
            'id'      => 'google_fonts_header',
            'desc'    => 'Enter the CSS Codes of the Google Font you\'ve selected for site\'s headers font. (h1, h2, h3, h4, h5, h6)',
			'section' => 'font-settings',
            'std'     => '',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
          ),
	  
	array(
        'label'       => 'Site General Font Size',
        'id'          => 'site_font_size',
        'type'        => 'measurement',
        'desc'        => 'Set the site general font size',
        'std'         => array(0=>"13",1=>"px"),
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'font-settings'
      ),
	  
	  array(
        'label'       => 'Site Navigation (Menu) Font Size',
        'id'          => 'site_nav_font_size',
        'type'        => 'measurement',
        'desc'        => 'Set site\'s navigation (menu) font size',
        'std'         => array(0=>"14",1=>"px"),
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'font-settings'
      ),
	  /*
	  	END OF FONT SETTINGS
	  */
	  
	  /*
	  	BACKGROUND SETTINGS
	  */
	  
      array(
        'id'          => 'background_texture',
        'label'       => 'Background Texture',
        'desc'        => 'Choose a texture for your background. If you don\'t want to use texture background choose "No Texture".',
        'std'         => F_WAY . '/images/grey.png',
        'type'        => 'radio-image',
        'section'     => 'background-settings',
        'class'       => '',
        'choices'     => array(
          array(
            'value'   => F_WAY . '/images/furley_bg.png',
            'label'   => 'Furley',
            'src'     => F_WAY . '/images/furley_bg_small.png'
          ),
          array(
            'value'   => F_WAY . '/images/bright_squares.png',
            'label'   => 'Bright Squares',
            'src'     => F_WAY . '/images/bright_squares_small.png'
          ),
          array(
            'value'   => F_WAY . '/images/diamond_upholstery.png',
            'label'   => 'Diamond Upholstery',
            'src'     => F_WAY . '/images/diamond_upholstery_small.png'
          ),
          array(
            'value'   => F_WAY . '/images/grey.png',
            'label'   => 'Grey',
            'src'     => F_WAY . '/images/grey_small.png'
          ),
		  array(
            'value'   => '',
            'label'   => 'No Texture',
            'src'     => F_WAY . '/images/no-texture.png'
          )
        )
      ),
	  
      array(
        'id'          => 'icemag_style',
        'label'       => 'Header Text Line Style',
        'desc'        => 'Choose the header text line style',
        'std'         => F_WAY . '/images/images/cross-line-bg.png',
        'type'        => 'radio-image',
        'section'     => 'background-settings',
        'class'       => '',
        'choices'     => array(
          array(
            'value'   => F_WAY . '/images/images/dots.png',
            'label'   => 'Dots',
            'src'     => F_WAY . '/images/images/icemag_header_small.png'
          ),
          array(
            'value'   => F_WAY . '/images/images/cross-line-bg.png',
            'label'   => 'Lines',
            'src'     => F_WAY . '/images/images/lined_header_small.png'
          ),
        )
      ),
	  
	  	  
	array(
        'label'       => 'Site Footer Background Texture',
        'id'          => 'upload_footer_texture',
        'type'        => 'upload',
        'desc'        => 'If you want to change the footer background image, upload any background image here. If you want to use the default, do not upload any image.',
        'std'         => '',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'background-settings'
      ),
	  
	array(
        'label'       => 'Header Background Image',
        'id'          => 'upload_header_bg_image',
        'type'        => 'upload',
        'desc'        => 'If you want to change the header background image, upload any background image here. If you want to use the default, do not upload any image.',
        'std'         => F_WAY.'/images/images/header-bg-small.png',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'section'     => 'background-settings'
      ),
	  	  
    )
  );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}
?>